﻿using Infragistics;
using Infragistics.Controls;
using Infragistics.Controls.Charts;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Windows;

namespace DrawingApp
{ 
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            
            this.Diagram.PropertyChanged += Diagram_PropertyChanged;
             
            this.Loaded += (s, e) => Diagram.ScaleToFit(); 
        } 

        private void Diagram_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            // synconize WindowRect of XamDiagram with WindowRect of XamDataChart
            if (e.PropertyName == "WindowRect")
            {
                // convert XamDiagram coordinates to XamDataChart coordinates
                var x = this.Diagram.WindowRect.X / this.Diagram.ViewportRect.Width / 10;
                var y = this.Diagram.WindowRect.Y / this.Diagram.ViewportRect.Height / 10;

                var w = this.Diagram.WindowRect.Width / this.Diagram.ViewportRect.Width / 10;
                var h = this.Diagram.WindowRect.Height / this.Diagram.ViewportRect.Height / 10;

                if (x < 0)
                {
                    w -= x; x = 0;
                }
                if (y < 0)
                {
                    h -= y; y = 0;
                }

                var rect = new Rect(x, y, w, h); 

                //Debug.WriteLine("Diagram_PropertyChanged " + e.PropertyName +
                //    " ViewportRect " + this.Diagram.ViewportRect +
                //    " ActualWidth " + this.Diagram.ActualWidth +
                //    " ActualHeight " + this.Diagram.ActualHeight+
                //    " WindowRect " + this.Diagram.WindowRect +
                //    " WindowRectC " + rect +
                //    " WorldRect " + this.Diagram.WorldRect  );

                RulerChart.WindowRect = rect; 
            }

            // synconize WorldRect of XamDiagram with Axis Min/Max values in XamDataChart
            if (e.PropertyName == "WorldRect")
            {
                Debug.WriteLine("Diagram_PropertyChanged " +
                     " WorldRect " + this.Diagram.WorldRect );
               
                var worldRect = this.Diagram.WorldRect;

                this.BottomAxis.MinimumValue = worldRect.Left;
                this.BottomAxis.MaximumValue = worldRect.Right; 
                this.TopAxis.MinimumValue = worldRect.Left;
                this.TopAxis.MaximumValue = worldRect.Right;

                this.LeftAxis.MinimumValue = worldRect.Top;
                this.LeftAxis.MaximumValue = worldRect.Bottom; 
                this.RightAxis.MinimumValue = worldRect.Top;
                this.RightAxis.MaximumValue = worldRect.Bottom;


            }

        }
               
        private void ToolsRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            if (this.Diagram != null)
            {
                if (sender.ToString() == "Pointer")
                {
                    this.Diagram.Tool = DiagramTool.Pointer;
                }
                else
                {
                    this.Diagram.Tool = DiagramTool.Connector;
                }
            }
        }

        private void ConnectionsDisplayModeRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            if (this.Diagram != null)
            {
                if (sender.ToString() == "Always")
                {
                    this.Diagram.ConnectionPointsDisplayMode = DiagramConnectionPointsDisplayMode.Always;
                }
                else if (sender.ToString() == "Auto")
                {
                    this.Diagram.ConnectionPointsDisplayMode = DiagramConnectionPointsDisplayMode.Auto;
                }
                else if (sender.ToString() == "MouseOver")
                {
                    this.Diagram.ConnectionPointsDisplayMode = DiagramConnectionPointsDisplayMode.MouseOver;
                }
                else if (sender.ToString() == "Never")
                {
                    this.Diagram.ConnectionPointsDisplayMode = DiagramConnectionPointsDisplayMode.Never;
                }
            }
        }

        private void DragInteractionRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            if (this.Diagram != null)
            {
                if (sender.ToString() == "None")
                {
                    this.Diagram.DefaultDragInteraction = DiagramDragInteraction.None;
                }
                else if (sender.ToString() == "Pan")
                {
                    this.Diagram.DefaultDragInteraction = DiagramDragInteraction.Pan;
                }
                else if (sender.ToString() == "Select")
                {
                    this.Diagram.DefaultDragInteraction = DiagramDragInteraction.Select;
                }
                else if (sender.ToString() == "Zoom")
                {
                    this.Diagram.DefaultDragInteraction = DiagramDragInteraction.Zoom;
                }
            }
        }

    }
}
